# aiontutil

AIONT utility package

## Install

Method 1:

```bash
pip install aiontutil
```

Method 2:

```bash
git clone git@github.com:aiont-joelan/aiontutil.git
cd aiontutil/
make build
cd dist/
pip install aiontutil-x.y.z-py3-none-any.whl
```

## Testing

```bash
make test
```
